@@ -1,24 +1,23 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of this
 # repository contains the full copyright notices and license terms.
-import datetime
 import calendar
+import datetime
 from decimal import Decimal
-from dateutil import relativedelta
-from dateutil import rrule
 from itertools import groupby
 
+from dateutil import relativedelta, rrule
+
 from trytond.i18n import gettext
-from trytond.model import Workflow, ModelSQL, ModelView, fields, Unique
+from trytond.model import ModelSQL, ModelView, Unique, Workflow, fields
 from trytond.model.exceptions import AccessError
-from trytond.pyson import Eval, Bool, If
-from trytond.pool import Pool
-from trytond.tools import cached_property
-from trytond.transaction import Transaction
-from trytond.wizard import (Wizard, StateView, StateTransition, StateReport,
-    Button)
-from trytond.tools import grouped_slice
 from trytond.modules.company import CompanyReport
 from trytond.modules.currency.fields import Monetary
+from trytond.pool import Pool
+from trytond.pyson import Bool, Eval, If
+from trytond.tools import cached_property, grouped_slice
+from trytond.transaction import Transaction
+from trytond.wizard import (
+    Button, StateReport, StateTransition, StateView, Wizard)
 
 from .exceptions import PrintDepreciationTableError
 
@@ -59,7 +58,7 @@ class Asset(Workflow, ModelSQL, ModelView):
         context={
             'company': Eval('company', None),
             },
-        depends=['state', 'company'],
+        depends={'company'},
         domain=[
             ('type', '=', 'assets'),
             ('depreciable', '=', True),
@@ -79,8 +78,7 @@ class Asset(Workflow, ModelSQL, ModelView):
             ],
         states={
             'readonly': (Eval('lines', [0]) | (Eval('state') != 'draft')),
-            },
-        depends=['product', 'state', 'company'])
+            })
     customer_invoice_line = fields.Function(fields.Many2One(
             'account.invoice.line', 'Customer Invoice Line'),
         'get_customer_invoice_line')
@@ -88,14 +86,12 @@ class Asset(Workflow, ModelSQL, ModelView):
         states={
             'readonly': Eval('state') != 'draft',
             },
-        depends=['state'],
         domain=[('type', '=', 'asset')],
         required=True)
     company = fields.Many2One('company.company', 'Company',
         states={
             'readonly': Eval('state') != 'draft',
             },
-        depends=['state'],
         required=True)
     currency = fields.Function(fields.Many2One('currency.currency',
         'Currency'), 'on_change_with_currency')
@@ -105,20 +101,17 @@ class Asset(Workflow, ModelSQL, ModelView):
             'readonly': (Bool(Eval('supplier_invoice_line', 1))
                 | Eval('lines', [0])
                 | (Eval('state') != 'draft')),
-            },
-        depends=['state'])
+            })
     unit = fields.Many2One('product.uom', 'Unit',
         states={
             'readonly': (Bool(Eval('product'))
                 | (Eval('state') != 'draft')),
-            },
-        depends=['state'])
+            })
     value = Monetary(
         "Value", currency='currency', digits='currency',
         states={
             'readonly': (Eval('lines', [0]) | (Eval('state') != 'draft')),
             },
-        depends=['state'],
         required=True,
         help="The value of the asset when purchased.")
     depreciated_amount = Monetary(
@@ -129,7 +122,6 @@ class Asset(Workflow, ModelSQL, ModelView):
         states={
             'readonly': (Eval('lines', [0]) | (Eval('state') != 'draft')),
             },
-        depends=['value', 'state'],
         required=True,
         help="The amount already depreciated at the start date.")
     depreciating_value = fields.Function(Monetary(
@@ -144,36 +136,31 @@ class Asset(Workflow, ModelSQL, ModelView):
             ],
         states={
             'readonly': (Eval('lines', [0]) | (Eval('state') != 'draft')),
-            },
-        depends=['depreciating_value', 'state'])
+            })
     purchase_date = fields.Date('Purchase Date', states={
             'readonly': (Bool(Eval('supplier_invoice_line', 1))
                 | Eval('lines', [0])
                 | (Eval('state') != 'draft')),
             },
-        required=True,
-        depends=['state'])
+        required=True)
     start_date = fields.Date('Start Date', states={
             'readonly': (Eval('lines', [0]) | (Eval('state') != 'draft')),
             },
         required=True,
-        domain=[('start_date', '<=', Eval('end_date', None))],
-        depends=['state', 'end_date'])
+        domain=[('start_date', '<=', Eval('end_date', None))])
     end_date = fields.Date('End Date',
         states={
             'readonly': (Eval('lines', [0]) | (Eval('state') != 'draft')),
             },
         required=True,
-        domain=[('end_date', '>=', Eval('start_date', None))],
-        depends=['state', 'start_date'])
+        domain=[('end_date', '>=', Eval('start_date', None))])
     depreciation_method = fields.Selection([
             ('linear', 'Linear'),
             ], 'Depreciation Method',
         states={
             'readonly': (Eval('lines', [0]) | (Eval('state') != 'draft')),
             },
-        required=True,
-        depends=['state'])
+        required=True)
     frequency = fields.Selection([
             ('monthly', 'Monthly'),
             ('yearly', 'Yearly'),
@@ -181,20 +168,18 @@ class Asset(Workflow, ModelSQL, ModelView):
         required=True,
         states={
             'readonly': (Eval('lines', [0]) | (Eval('state') != 'draft')),
-            },
-        depends=['state'])
+            })
     state = fields.Selection([
             ('draft', 'Draft'),
             ('running', 'Running'),
             ('closed', 'Closed'),
-            ], 'State', readonly=True)
+            ], "State", readonly=True, sort=False)
     lines = fields.One2Many('account.asset.line', 'asset', 'Lines',
         readonly=True)
     move = fields.Many2One('account.move', 'Account Move', readonly=True,
         domain=[
             ('company', '=', Eval('company', -1)),
-            ],
-        depends=['company'])
+            ])
     update_moves = fields.Many2Many('account.asset-update-account.move',
         'asset', 'move', 'Update Moves', readonly=True,
         domain=[
@@ -202,8 +187,7 @@ class Asset(Workflow, ModelSQL, ModelView):
             ],
         states={
             'invisible': ~Eval('update_moves'),
-            },
-        depends=['company'])
+            })
     comment = fields.Text('Comment')
     revisions = fields.One2Many(
         'account.asset.revision', 'asset', "Revisions", readonly=True)
@@ -598,7 +582,8 @@ class Asset(Workflow, ModelSQL, ModelView):
         MoveLine = pool.get('account.move.line')
 
         if date is None:
-            date = Date.today()
+            with Transaction().set_context(company=self.company.id):
+                date = Date.today()
         period_id = Period.find(self.company.id, date)
         if self.supplier_invoice_line:
             account_asset = self.supplier_invoice_line.account.current()
@@ -808,7 +793,6 @@ class UpdateAssetShowDepreciation(ModelView):
             ('date', '>=', Eval('latest_move_date')),
             ('date', '<=', Eval('next_depreciation_date')),
             ],
-        depends=['latest_move_date', 'next_depreciation_date'],
         help=('The date must be between the last update/depreciation date '
             'and the next depreciation date.'))
     latest_move_date = fields.Date('Latest Move Date', readonly=True)
@@ -1153,11 +1137,9 @@ class PrintDepreciationTableStart(ModelView):
     __name__ = 'account.asset.print_depreciation_table.start'
 
     start_date = fields.Date('Start Date', required=True,
-        domain=[('start_date', '<', Eval('end_date'))],
-        depends=['end_date'])
+        domain=[('start_date', '<', Eval('end_date'))])
     end_date = fields.Date('End Date', required=True,
-        domain=[('end_date', '>', Eval('start_date'))],
-        depends=['start_date'])
+        domain=[('end_date', '>', Eval('start_date'))])
 
     @staticmethod
     def default_start_date():
